@@ -7,10 +7,10 @@
 from squaternion.squaternion import Quaternion
 from squaternion.squaternion import Axis
 
-try:
-    from importlib.metadata import version # type: ignore
-except ImportError:
-    from importlib_metadata import version # type: ignore
+# try:
+from importlib.metadata import version # type: ignore
+# except ImportError:
+#     from importlib_metadata import version # type: ignore
 
 __author__ = "Kevin Walchko"
 __license__ = "MIT"
